# Generated by Django 3.1 on 2021-05-23 11:09

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, unique=True)),
                ('capital', models.CharField(blank=True, max_length=200, null=True, unique=True)),
                ('districts', models.PositiveIntegerField(blank=True, null=True)),
                ('postcode', models.CharField(blank=True, max_length=50, null=True, unique=True)),
                ('zone', models.CharField(blank=True, max_length=100, null=True)),
                ('population', models.IntegerField(blank=True, null=True)),
                ('area', models.CharField(blank=True, max_length=50, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='District',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True)),
                ('population', models.IntegerField(blank=True, null=True)),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='mikoa.region')),
            ],
        ),
    ]
